@@ -4,10 +4,10 @@
  * Please add your name here if you distribute modified versions.
  * 
  * FFindex is provided under the Create Commons license "Attribution-ShareAlike
- * 3.0", which basically captures the spirit of the Gnu Public License (GPL).
+ * 4.0", which basically captures the spirit of the Gnu Public License (GPL).
  * 
  * See:
- * http://creativecommons.org/licenses/by-sa/3.0/
+ * http://creativecommons.org/licenses/by-sa/4.0/
  *
  * ffindex_apply
  * apply a program to each FFindex entry
@@ -37,7 +37,7 @@ int main(int argn, char **argv)
     fprintf(stderr, "USAGE: %s DATA_FILENAME INDEX_FILENAME OUT_DIR\n"
                     "\n\tPlease note that a huge number of files might be created!\n"
                     FFINDEX_COPYRIGHT,
-                    argv[0]);
+                    basename(argv[0]));
     return -1;
   }
   char *data_filename  = argv[1];
